:mod:`trac.prefs.api` -- Trac Administration panels
===================================================

.. module :: trac.prefs.api

Primary interface for managing preference panels (tabs).


Interfaces
----------

.. autoclass :: IPreferencePanelProvider
   :members:

   See also :extensionpoints:`trac.prefs.api.IPreferencePanelProvider`
